
import random
import sys

import py_cui.errors

from qrogue.management import GameHandler
from qrogue.util import Config, Logger


def start_game():
    __CONSOLE_ARGUMENT = "--from-console"
    __DEBUG_ARGUMENT = "--debug"

    return_code = Config.load()  # NEEDS TO BE THE FIRST THING WE DO!
    if return_code == 0:
        if __DEBUG_ARGUMENT in sys.argv:
            Config.activate_debugging()
        seed = random.randint(0, Config.MAX_SEED)
        print(f"[Qrogue] Starting game with seed = {seed}")
        try:
            game = GameHandler(seed)
            game.start()
        except py_cui.errors.PyCUIOutOfBoundsError:
            #print("[Qrogue] ERROR!")
            #print("Your terminal window is too small. "
            #      "Please make it bigger (i.e. maximize it) or reduce the font size.")
            print("---------------------------------------------------------")
            exit(1)

        # flush after the player stopped playing
        Logger.instance().flush()
        print("[Qrogue] Successfully flushed all logs and shut down the game without any problems. See you next time!")
    else:
        print(f"[Qrogue] Error #{return_code}:")
        if return_code == 1:
            print("qrogue.config is invalid. Please check if the second line describes a valid path (the path "
                  "to your save files). Using special characters in the path could also cause this error so if the path is "
                  "valid please consider using another one without special characters.")

    if __CONSOLE_ARGUMENT not in sys.argv:
        print()
        input("[Qrogue] Press ENTER to close the application")

    exit(return_code)



from distutils.core import setup
setup(
  name = 'qrogue',         # Name of package folder
  packages = ['qrogue'],   # Same as "name"
  version = '0.2.1.2',
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Qrogue is a modernized Quantum Computing take of the classical game Rogue. It can be played in a '
                'terminal and aims to improve your understanding of Quantum Computing',
  author = 'Michael Artner',
  author_email = 'michael.artner@jku.at',
  url = 'https://github.com/7Magic7Mike7/Qrogue',
  download_url = 'https://github.com/7Magic7Mike7/Qrogue/releases/tag/0.2.1.1',    # link to Release on GitHub
  keywords = ['Quantum Computing', 'Gamification', 'Video Game', 'PyCUI'],
  install_requires=[
          'py-cui',
          'qiskit',
    # todo
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable"
    'Intended Audience :: Education',
    'Intended Audience :: Science/Research',
    'Topic :: Games/Entertainment :: Puzzle Games',
    'Programming Language :: Python :: 3.8',
  ],
)